==> spip_4.0.4.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'به هنگام سازي تمام يو.آر.ال ها (URLs)',

	// B
	'bouton_supprimer_url' => 'حذف اين يو.آر.ال',

	// E
	'erreur_arbo_2_segments_max' => 'نمي‌توانيد براي يك چيز بيش دو قطعه‌ از يو.آر.ال استفاده كنيد',
	'erreur_config_url_forcee' => 'پيكربندي يو.آر.ال‌ها در پرونده‌ي  <tt>mes_options.php</tt> تنظيم مي‌شود. ',
	'explication_editer' => 'مديريت پيشرفته‌ي يو.آر.ال‌ها به شما ازجاه مي‌دهد تا تو.آر.ال صفحه‌هاي هر مووضوع ويرايشي را ويرايش كنيد و تاريخچه‌ي تغيير آن‌ها را مديريت نماييد. 
',

	// I
	'icone_configurer_urls' => 'پيكربندي يو.آر.آل‌‌ها',
	'icone_controler_urls' => 'يو.آر.ال هاي صحيح',
	'info_1_url' => 'يو.آر.ال 1',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ يو.آر.ال',
	'info_objet' => 'چيز',

	// L
	'label_tri_date' => 'تاريخ',
	'label_tri_id' => 'آي.دي (شناشه)',
	'label_tri_url' => 'يو.آر.ال',
	'label_url' => 'يو.آر.ال جديد',
	'label_url_minuscules_0' => 'حفظ شكستگي تيتر',
	'label_url_minuscules_1' => 'الزام يو.آر.ال‌ها به حروف كوچك',
	'label_url_permanente' => ' قف كردن اين يو.ار.ال (بعد از اصلاح اين سوژه به هنگام سازي نمي‌شود). ',
	'label_url_sep_id' => 'كاراكتر براي جدا كردن شماره‌ي افزوده شده در مورد جفت',
	'label_urls_activer_controle_oui' => 'فعال سازي مديريت پيشرفته‌ي يو.آر.ال‌ها',
	'label_urls_nb_max_car' => 'بيشترين تعداد كاراكتر‌ها',
	'label_urls_nb_min_car' => 'كم‌ترين تعداد كاراركتر‌ها',
	'liberer_url' => 'آزادسازي',
	'liste_des_urls' => 'تمام يو.آر.ال‌ ها',

	// T
	'texte_type_urls' => 'در زير مي‌توانيد حالت محاسبه‌ي نشاني صفحه‌ها را گزينش كنيد.',
	'texte_type_urls_attention' => 'توجه! اين تنظيم فقط هنگامي كار خواهد كرد كه فايل @htaccess@ در ريشه‌ي سايت نصب شده باشد.',
	'texte_urls_nb_max_car' => 'اگر تيتر زياد بزرگ باشد، شكسته خواهد شد.',
	'texte_urls_nb_min_car' => 'اگر تيتر خيلي كوتاه باشد، شماره‌ي شناسه‌ي آن مورد استفاده قرار خواهد گرفت.',
	'titre_gestion_des_urls' => 'مديريت يو.آر.ال‌ها',
	'titre_type_arbo' => 'يو.آر.ال‌هاي درختي',
	'titre_type_html' => 'يو.ار.ال چيزهاي اچ‌تي‌ام‌ال',
	'titre_type_libres' => 'يو.ار.ال‌هاي آزاد',
	'titre_type_page' => 'صفحه‌ي يو.آر.ال‌ها',
	'titre_type_propres' => 'يو.آر.ال‌هاي صحيح',
	'titre_type_propres2' => 'يو.آر.ال‌هاي پيشنهادي +<tt>.html</tt>',
	'titre_type_propres_qs' => 'يو.آر.ال‌هاي پيشنهادي در زنجيره‌ي پرسشنامه',
	'titre_type_simple' => 'يو.آر.ال‌هاي ساده',
	'titre_type_standard' => 'يو.آر.ال‌هاي تاريخي',
	'titre_type_urls' => 'نوع نشاني‌هاي URL',
	'tout_voir' => 'تمام يو.آر.ال‌ها را بنگريد',

	// U
	'url_ajout_impossible' => 'خطايي رخ داده است. ثبت اين يو.آر.ال ممكن نيست. ',
	'url_ajoutee' => 'يو.آر.ال افزوده شد',

	// V
	'verifier_url_nettoyee' => 'يو.آر.ال تصحيح شد. مي‌توانيد قبل از ثبت چك كنيد.',
	'verrouiller_url' => 'توقيف'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// A
	'actualiser_toutes' => 'به هنگام سازي تمام يو.آر.ال ها (URLs)',

	// B
	'bouton_supprimer_url' => 'حذف اين يو.آر.ال',

	// E
	'erreur_arbo_2_segments_max' => 'نمي‌توانيد براي يك چيز بيش دو قطعه‌ از يو.آر.ال استفاده كنيد',
	'erreur_config_url_forcee' => 'پيكربندي يو.آر.ال‌ها در پرونده‌ي  <tt>mes_options.php</tt> تنظيم مي‌شود. ',
	'explication_editer' => 'مديريت پيشرفته‌ي يو.آر.ال‌ها به شما ازجاه مي‌دهد تا تو.آر.ال صفحه‌هاي هر مووضوع ويرايشي را ويرايش كنيد و تاريخچه‌ي تغيير آن‌ها را مديريت نماييد. 
',

	// I
	'icone_configurer_urls' => 'پيكربندي يو.آر.آل‌‌ها',
	'icone_controler_urls' => 'يو.آر.ال هاي صحيح',
	'info_1_url' => 'يو.آر.ال 1',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ يو.آر.ال',
	'info_objet' => 'چيز',

	// L
	'label_tri_date' => 'تاريخ',
	'label_tri_id' => 'آي.دي (شناشه)',
	'label_tri_url' => 'يو.آر.ال',
	'label_url' => 'يو.آر.ال جديد',
	'label_url_minuscules_0' => 'حفظ شكستگي تيتر',
	'label_url_minuscules_1' => 'الزام يو.آر.ال‌ها به حروف كوچك',
	'label_url_permanente' => ' قف كردن اين يو.ار.ال (بعد از اصلاح اين سوژه به هنگام سازي نمي‌شود). ',
	'label_url_sep_id' => 'كاراكتر براي جدا كردن شماره‌ي افزوده شده در مورد جفت',
	'label_urls_activer_controle_oui' => 'فعال سازي مديريت پيشرفته‌ي يو.آر.ال‌ها',
	'label_urls_nb_max_car' => 'بيشترين تعداد كاراكتر‌ها',
	'label_urls_nb_min_car' => 'كم‌ترين تعداد كاراركتر‌ها',
	'liberer_url' => 'آزادسازي',
	'liste_des_urls' => 'تمام يو.آر.ال‌ ها',

	// T
	'texte_type_urls' => 'در زير مي‌توانيد حالت محاسبه‌ي نشاني صفحه‌ها را گزينش كنيد.',
	'texte_type_urls_attention' => 'توجه! اين تنظيم فقط هنگامي كار خواهد كرد كه فايل @htaccess@ در ريشه‌ي سايت نصب شده باشد.',
	'texte_urls_nb_max_car' => 'اگر تيتر زياد بزرگ باشد، شكسته خواهد شد.',
	'texte_urls_nb_min_car' => 'اگر تيتر خيلي كوتاه باشد، شماره‌ي شناسه‌ي آن مورد استفاده قرار خواهد گرفت.',
	'titre_gestion_des_urls' => 'مديريت يو.آر.ال‌ها',
	'titre_type_arbo' => 'يو.آر.ال‌هاي درختي',
	'titre_type_html' => 'يو.ار.ال چيزهاي اچ‌تي‌ام‌ال',
	'titre_type_libres' => 'يو.ار.ال‌هاي آزاد',
	'titre_type_page' => 'صفحه‌ي يو.آر.ال‌ها',
	'titre_type_propres' => 'يو.آر.ال‌هاي صحيح',
	'titre_type_propres2' => 'يو.آر.ال‌هاي پيشنهادي +<tt>.html</tt>',
	'titre_type_propres_qs' => 'يو.آر.ال‌هاي پيشنهادي در زنجيره‌ي پرسشنامه',
	'titre_type_simple' => 'يو.آر.ال‌هاي ساده',
	'titre_type_standard' => 'يو.آر.ال‌هاي تاريخي',
	'titre_type_urls' => 'نوع نشاني‌هاي URL',
	'tout_voir' => 'تمام يو.آر.ال‌ها را بنگريد',

	// U
	'url_ajout_impossible' => 'خطايي رخ داده است. ثبت اين يو.آر.ال ممكن نيست. ',
	'url_ajoutee' => 'يو.آر.ال افزوده شد',

	// V
	'verifier_url_nettoyee' => 'يو.آر.ال تصحيح شد. مي‌توانيد قبل از ثبت چك كنيد.',
	'verrouiller_url' => 'توقيف',
];
